==> eiffelstudio-18.07.10.1981.tar: F_code/C39/co1935.c <==
/*
 * Code for class CONF_SETTING
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co1935.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_SETTING}.make */
void F2852_32800 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(50, 0).id);
	F51_822(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CONF_SETTING}.initialize */
void F2852_32802 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		{
			/* INLINED CODE (initialize_conf_location_mapper) */
			if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
				F2852_32808(Current);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_);
			}
			/* END INLINED CODE */
		}
		;
		*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_);
	}
	RTLE;
}

/* {CONF_SETTING}.conf_location_mapper */
EIF_REFERENCE F2852_32803 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CONF_SETTING}.initialize_conf_location_mapper */
void F2852_32806 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
		F2852_32808(Current);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_);
	}
	RTLE;
}

/* {CONF_SETTING}.initialize_iron */
void F2852_32808 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,loc1);
	RTLIU(6);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_)) {
		{
			/* INLINED CODE (is_eiffel_layout_defined) */
			tb1 = (EIF_BOOLEAN)  0;
			tr1 = RTOSCF(15551,F1622_15551,(Current));
			tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tr1 != NULL);
			/* END INLINED CODE */
		}
		if (tb1) {
			tr1 = RTLNS(eif_new_type(1566, 0x00).id, 1566, _OBJSIZ_2_0_0_0_0_0_0_0_);
			tr2 = F3106_37270(RTCV(F1622_15550(Current)));
			tr3 = F3106_37269(RTCV(F1622_15550(Current)));
			F1567_14996(RTCW(tr1), tr2, tr3);
			loc2 = (EIF_REFERENCE) tr1;
			tr1 = RTLNS(eif_new_type(240, 0x00).id, 240, _OBJSIZ_3_0_0_0_0_0_0_0_);
			tr2 = RTLNS(eif_new_type(53, 0x00).id, 53, _OBJSIZ_0_0_0_0_0_0_0_0_);
			F241_4016(RTCW(tr1), loc2, tr2);
			loc1 = (EIF_REFERENCE) tr1;
			tr1 = *(EIF_REFERENCE *)(Current);
			{
				/* INLINED CODE (register) */
				tr2 = *(EIF_REFERENCE *)(RTCW(tr1));
				F1486_14590(RTCW(tr2), loc1);
				/* END INLINED CODE */
			}
			;
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTLE;
}

void EIF_Minit1935 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C39/co1935.c <==
/*
 * Code for class CONF_SETTING
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co1935.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_SETTING}.make */
void F2876_32716 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(51, 0).id);
	F52_882(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CONF_SETTING}.initialize */
void F2876_32718 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		{
			/* INLINED CODE (CONF_SETTING.initialize_conf_location_mapper) */
			if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
				F2876_32724(Current);
				*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_);
			}
			/* END INLINED CODE */
		}
		;
		*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_);
	}
	RTLE;
}

/* {CONF_SETTING}.initialize_conf_location_mapper */
void F2876_32722 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
		F2876_32724(Current);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_);
	}
	RTLE;
}

/* {CONF_SETTING}.initialize_iron */
void F2876_32724 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,tr2);
	RTLR(4,loc1);
	RTLIU(5);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_)) {
		{
			/* INLINED CODE (EIFFEL_LAYOUT.is_eiffel_layout_defined) */
			tb1 = (EIF_BOOLEAN)  0;
			tr1 = RTOSCF(15732,F1651_15732, (Current));
			tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tr1 != NULL);
			/* END INLINED CODE */
		}
		if (tb1) {
			loc2 = RTLNS(eif_new_type(949, 0x00).id, 949, _OBJSIZ_2_0_0_0_0_0_0_0_);
			tr1 = F3152_37798(RTCV(F1651_15731(Current)));
			tr2 = F3152_37797(RTCV(F1651_15731(Current)));
			F950_13356(RTCW(loc2), tr1, tr2);
			loc1 = RTLNS(eif_new_type(243, 0x00).id, 243, _OBJSIZ_3_0_0_0_0_0_0_0_);
			tr1 = RTLNS(eif_new_type(53, 0x00).id, 53, _OBJSIZ_0_0_0_0_0_0_0_0_);
			F244_4118(RTCW(loc1), loc2, tr1);
			tr1 = *(EIF_REFERENCE *)(Current);
			{
				/* INLINED CODE (CONF_LOCATION_MAPPER.register) */
				tr2 = *(EIF_REFERENCE *)(RTCW(tr1));
				F1523_14980(RTCW(tr2), loc1);
				/* END INLINED CODE */
			}
			;
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTLE;
}

void EIF_Minit1935 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
